@@ -90,6 +90,9 @@ import opentelemetry.trace as trace_api
 import pkg_resources
 from google.cloud.trace_v2 import BatchWriteSpansRequest, TraceServiceClient
 from google.cloud.trace_v2 import types as trace_types
+from google.cloud.trace_v2.services.trace_service.transports import (
+    TraceServiceGrpcTransport,
+)
 from google.protobuf.timestamp_pb2 import (  # pylint: disable=no-name-in-module
     Timestamp,
 )
@@ -113,6 +116,18 @@ from opentelemetry.util import types
 
 logger = logging.getLogger(__name__)
 
+_OTEL_SDK_VERSION = pkg_resources.get_distribution("opentelemetry-sdk").version
+_USER_AGENT = f"opentelemetry-python {_OTEL_SDK_VERSION}; google-cloud-trace-exporter {__version__}"
+
+# Set user-agent metadata, see https://github.com/grpc/grpc/issues/23644 and default options
+# from
+# https://github.com/googleapis/python-trace/blob/v1.7.3/google/cloud/trace_v1/services/trace_service/transports/grpc.py#L177-L180
+_OPTIONS = [
+    ("grpc.max_send_message_length", -1),
+    ("grpc.max_receive_message_length", -1),
+    ("grpc.primary_user_agent", _USER_AGENT),
+]
+
 MAX_NUM_LINKS = 128
 MAX_NUM_EVENTS = 32
 MAX_EVENT_ATTRS = 4
@@ -141,7 +156,14 @@ class CloudTraceSpanExporter(SpanExporter):
         client=None,
         resource_regex=None,
     ):
-        self.client: TraceServiceClient = client or TraceServiceClient()
+        self.client: TraceServiceClient = client or TraceServiceClient(
+            transport=TraceServiceGrpcTransport(
+                channel=TraceServiceGrpcTransport.create_channel(
+                    options=_OPTIONS
+                )
+            )
+        )
+
         if not project_id:
             project_id = environ.get(OTEL_EXPORTER_GCP_TRACE_PROJECT_ID)
         if not project_id:
@@ -230,8 +252,8 @@ class CloudTraceSpanExporter(SpanExporter):
                         MAX_SPAN_ATTRS,
                         add_agent_attr=True,
                     ),
-                    links=_extract_links(span.links),  # type: ignore[has-type]
-                    status=_extract_status(span.status),  # type: ignore[arg-type]
+                    links=_extract_links(span.links),
+                    status=_extract_status(span.status),
                     time_events=_extract_events(span.events),
                     span_kind=_extract_span_kind(span.kind),
                 )
@@ -281,7 +303,7 @@ def _extract_status(status: trace_api.Status) -> Optional[status_pb2.Status]:
         status_proto = status_pb2.Status(code=code_pb2.OK)
     elif status.status_code is StatusCode.ERROR:
         status_proto = status_pb2.Status(
-            code=code_pb2.UNKNOWN, message=status.description
+            code=code_pb2.UNKNOWN, message=status.description or ""
         )
     # future added value
     else:
@@ -290,7 +312,7 @@ def _extract_status(status: trace_api.Status) -> Optional[status_pb2.Status]:
             status.status_code,
         )
         status_proto = status_pb2.Status(
-            code=code_pb2.UNKNOWN, message=status.description
+            code=code_pb2.UNKNOWN, message=status.description or ""
         )
 
     return status_proto
@@ -471,9 +493,9 @@ def _extract_attributes(
     add_agent_attr: bool = False,
 ) -> trace_types.Span.Attributes:
     """Convert span.attributes to dict."""
-    attributes_dict = BoundedDict(
-        num_attrs_limit
-    )  # type: BoundedDict[str, trace_types.AttributeValue]
+    attributes_dict: BoundedDict[
+        str, trace_types.AttributeValue
+    ] = BoundedDict(num_attrs_limit)
     invalid_value_dropped_count = 0
     for ot_key, ot_value in attrs.items() if attrs else []:
         key = _truncate_str(ot_key, MAX_ATTR_KEY_BYTES)[0]
